@@ -1,3 +1,19 @@
+#    map bioconductor classes to Python classes 
+#    Copyright (C) 2009-2010  Laurent Gautier
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 """
 A module to model the Biostrings library in Bioconductor
 
@@ -13,6 +29,7 @@ conversion = robjects.conversion
 import iranges
 from rpy2.robjects.packages import importr
 
+base = importr('base')
 methods = importr('methods')
 getmethod = methods.getMethod
 __rname__ = 'Biostrings'
@@ -124,16 +141,19 @@ class XStringSet(rpy2.robjects.methods.RS4):
     _subset = getmethod("[", 
                         signature = "XStringSet",
                         where = "package:Biostrings")
+    _length = base.length
 
     r = None
     
-
-
     def subset(self, x):
         res = self._subset(self, x)
         return res
 
-    
+    #FIXME: should implement an rpy2-defined sequence interface ?
+    def __len__(self):
+        res = self._length(self)[0]
+        return res
+
 class BStringSet(XStringSet):
     ''' Set of biological strings '''
     _bstringset_constructor = biostrings.BStringSet
